============
nanosphere
============

A collection of useful nanoservices.


### Usage:

````shell
$ nanosphere-sms start --config etc/nanosphere.sms.json
```

* Same routine for other services: `nanosphere-auth`, `nanosphere-push`, etc.
* Example config files `./etc/*`